@@ -104,7 +104,7 @@ struct flag {
 	unsigned short amii_dripens[ 20 ]; /* DrawInfo Pens currently there are 13 in v39 */
 	AMII_COLOR_TYPE amii_curmap[ AMII_MAXCOLORS ]; /* colormap */
 #endif
-#ifdef REPORTSCORE
+#ifdef NH_EXTENSION_REPORT
 	boolean	reportscore;
 #endif
 
