@@ -6,7 +6,7 @@
 #include "dgn_file.h"
 #include "dlb.h"
 
-#ifdef _MSC_VER
+#if defined(_MSC_VER) && !defined(WIN32)
 #include "../japanese/emalloc.h"
 #define alloc(s) emalloc(s)
 #endif
