@@ -40,6 +40,7 @@ NetHack, except that rounddiv may call panic().
 	void		setrandom	(void)
 	int		getyear		(void)
 	char *		yymmdd		(time_t)
+	long		yyyymmdd	(time_t)
 	int		phase_of_the_moon	(void)
 	boolean		friday_13th	(void)
 	int		night		(void)
@@ -412,7 +413,7 @@ strstri(str, sub)	/* case insensitive substring search */
  *
  * The time is used for:
  *	- seed for rand()
- *	- year on tombstone and yymmdd in record file
+ *	- year on tombstone and yyyymmdd in record file
  *	- phase of the moon (various monsters react to NEW_MOON or FULL_MOON)
  *	- night and midnight (the undead are dangerous at midnight)
  *	- determination of what files are "very old"
@@ -474,6 +475,7 @@ getyear()
 	return(1900 + getlt()->tm_year);
 }
 
+/* This routine is no longer used since in 2000 it will yield "100mmdd". */
 char *
 yymmdd(date)
 time_t date;
@@ -503,6 +505,35 @@ time_t date;
 	return(datestr);
 }
 
+long
+yyyymmdd(date)
+time_t date;
+{
+	long datenum;
+	struct tm *lt;
+
+	if (date == 0)
+		lt = getlt();
+	else
+#if (defined(ULTRIX) && !(defined(ULTRIX_PROTO) || defined(NHSTDC))) || defined(BSD)
+		lt = localtime((long *)(&date));
+#else
+		lt = localtime(&date);
+#endif
+
+	/* just in case somebody's localtime supplies (year % 100)
+	   rather than the expected (year - 1900) */
+	if (lt->tm_year < 70)
+	    datenum = (long)lt->tm_year + 2000L;
+	else
+	    datenum = (long)lt->tm_year + 1900L;
+	/* yyyy --> yyyymm */
+	datenum = datenum * 100L + (long)(lt->tm_mon + 1);
+	/* yyyymm --> yyyymmdd */
+	datenum = datenum * 100L + (long)lt->tm_mday;
+	return datenum;
+}
+
 /*
  * moon period = 29.53058 days ~= 30, year = 365.2422 days
  * days moon phase advances on first day of year compared to preceding year
