@@ -4,7 +4,7 @@
 
 /*
 **	Japanese version Copyright
-**	(c) Issei Numata, Naoki Hamada, Shigehiro Miyashita, 1994-1999
+**	(c) Issei Numata, Naoki Hamada, Shigehiro Miyashita, 1994-2000
 **	changing point is marked `JP' (94/6/7)
 **	JNetHack may be freely redistributed.  See license for details. 
 */
@@ -452,7 +452,7 @@ struct obj *otmp;
 	char *junk[]={
 /*JP
 	"Please disregard previous letter.",
-	"Welcome to NetHack 3.2.2!",
+	"Welcome to NetHack 3.2.3!",
 */
 	"Υ᡼˺Ƥ",
 	"NetHack 3.2.2ؤ褦",
@@ -461,11 +461,17 @@ struct obj *otmp;
 	"CATS have all the answers.",
 #endif
 /*JP
-	"Report bugs to nethack-bugs@linc.cis.upenn.edu"
+	"Report bugs to <nethack-bugs@nethack.org>"
 */
-	"ХݡȤ jnethack-bugs@norisuke.jaist.ac.jp "
+	"ХݡȤ jnethack-bugs@jnethack.org "
 	};
 
+    if (Blind)
+/*JP
+	pline("Unfortunately you cannot see what it says.");
+*/
+	pline("ԹˤⲿȽ񤤤ƤΤ뤳ȤǤʤ");
+    else
 /*JP
 	pline("It reads:  \"%s\"", junk[rn2(SIZE(junk))]);
 */
