@@ -4,7 +4,7 @@
 
 /*
 **	Japanese version Copyright
-**	(c) Issei Numata, Naoki Hamada, Shigehiro Miyashita, 1994-1999
+**	(c) Issei Numata, Naoki Hamada, Shigehiro Miyashita, 1994-2000
 **	changing point is marked `JP' (94/6/7)
 **	JNetHack may be freely redistributed.  See license for details. 
 */
@@ -926,6 +926,8 @@ movebubbles()
 	if (!wportal) set_wportal();
 
 	vision_recalc(2);
+	/* keep attached ball&chain separate from bubble objects */
+	if (Punished) unplacebc();
 
 	/*
 	 * Pick up everything inside of a bubble then fill all bubble
@@ -1028,6 +1030,8 @@ movebubbles()
 			    FALSE);
 	}
 
+	/* put attached ball&chain back */
+	if (Punished) placebc();
 	vision_full_recalc = 1;
 }
 
@@ -1329,7 +1333,6 @@ register boolean ini;
 		    if (MON_AT(cons->x, cons->y)) {
 				mnexto(m_at(cons->x,cons->y));
 			}
-		    if (Punished) placebc();	/* do this for now */
 		    break;
 		}
 
