@@ -7,7 +7,7 @@
 
 /*
 **	Japanese version Copyright
-**	(c) Issei Numata, Naoki Hamada, Shigehiro Miyashita, 1994-1999
+**	(c) Issei Numata, Naoki Hamada, Shigehiro Miyashita, 1994-2000
 **	changing point is marked `JP' (94/6/7)
 **	JNetHack may be freely redistributed.  See license for details. 
 */
@@ -604,7 +604,7 @@ do_look(quick)
 
 	/* Finally, print out our explanation. */
 	if (found) {
-	    pline(out_str);
+	    pline("%s", out_str);
 	    /* check the data file for information about this thing */
 	    if (found == 1 && !quick && flags.help) {
 		char temp_buf[BUFSZ];
