@@ -4,7 +4,7 @@
 
 /*
 **	Japanese version Copyright
-**	(c) Issei Numata, Naoki Hamada, Shigehiro Miyashita, 1994-1999
+**	(c) Issei Numata, Naoki Hamada, Shigehiro Miyashita, 1994-2000
 **	changing point is marked `JP' (94/6/7)
 **	JNetHack may be freely redistributed.  See license for details. 
 */
@@ -282,7 +282,8 @@ register int trouble;
 	    case TROUBLE_STUCK_IN_WALL:
 /*JP		    Your("surroundings change.");*/
 		    Your("ĶѲ");
-		    tele();
+		    /* no control, but works on no-teleport levels */
+		    (void) safe_teleds();
 		    break;
 	    case TROUBLE_CURSED_LEVITATION:
 		    if (uarmf && uarmf->otyp==LEVITATION_BOOTS
