@@ -4,7 +4,7 @@
 
 /*
 **	Japanese version Copyright
-**	(c) Issei Numata, Naoki Hamada, Shigehiro Miyashita, 1994-1999
+**	(c) Issei Numata, Naoki Hamada, Shigehiro Miyashita, 1994-2000
 **	changing point is marked `JP' (94/6/7)
 **	JNetHack may be freely redistributed.  See license for details. 
 */
@@ -2059,6 +2059,9 @@ boolean *lostsome;
 {
 	int invc = inv_cnt();
 
+	/* [TODO: drop u.ugold separately or insert it into inventory chain] */
+	if (invc == 0) return FALSE;	/* nothing to drop */
+
 	while (near_capacity() > (Punished ? UNENCUMBERED : SLT_ENCUMBER)) {
 		register struct obj *obj, *otmp = (struct obj *)0;
 		register int i = rn2(invc);
