@@ -52,9 +52,9 @@ extern short glyph2tile[];
 extern int total_tiles_used;
 
 /* Define these if you really want a lot of junk on your screen. */
-/* #define VERBOSE		/* print various info & events as they happen */
-/* #define VERBOSE_UPDATE	/* print screen update bounds */
-/* #define VERBOSE_INPUT	/* print input events */
+/* #define VERBOSE*/		/* print various info & events as they happen */
+/* #define VERBOSE_UPDATE*/	/* print screen update bounds */
+/* #define VERBOSE_INPUT*/	/* print input events */
 
 
 #define USE_WHITE	/* almost always use white as a tile cursor border */
@@ -419,7 +419,9 @@ init_tiles(wp)
 		    );
 
 	if (errorcode!=XpmSuccess) {
+#ifdef RADAR
 	    USE_RADAR = 0;
+#endif
 	    if (errorcode == XpmColorFailed) {
 		Sprintf(buf, "Insufficient colors available to load %s.",appResources.tile_file);
 		X11_raw_print(buf);
@@ -1774,6 +1776,7 @@ static char radar_translations[] =
 ";
 #endif
 
+#ifdef RADAR
 void
 dismiss_radar(Widget w, XEvent*ev , String *s, Cardinal*n)
 {
@@ -1781,6 +1784,7 @@ dismiss_radar(Widget w, XEvent*ev , String *s, Cardinal*n)
     flags.radar = FALSE;
     radar_is_popuped = FALSE;
 }
+#endif
 
 /*
  * The map window creation routine.
