@@ -366,7 +366,7 @@ tty_player_selection()
 	Strcat(pbuf, jtrns_mon(roles[i], -1));
 	Sprintf(eos(pbuf), "(%c)", roles[i][0]);
 /*JP	if (roles[i+1]) {*/
-	if (jtmp = jtrns_mon(roles[i+1], -1)) {
+	if ((jtmp = jtrns_mon(roles[i+1], -1)) != NULL) {
 	    Strcat(pbuf, ", ");
 /*JP	    if ((int)strlen(pbuf) + (int)strlen(roles[i+1]) + 8 > CO) {*/
 	    if ((int)strlen(pbuf) + (int)strlen(jtmp) + 11 > CO) {
@@ -1035,10 +1035,10 @@ struct WinDesc *cw;
 		    if (n == 2 && curr->identifier.a_void != 0 &&
 						    curr->selected) {
 			if (curr->count == -1L)
-/*JP			    (void) putchar('+'); /* all selected */
+/*JP			    (void) putchar('+');*/ /* all selected */
 			    (void) jputchar('+'); /* all selected */
 			else
-/*JP			    (void) putchar('#'); /* count selected */
+/*JP			    (void) putchar('#');*/ /* count selected */
 			    (void) jputchar('#'); /* count selected */
 		    } else
 /*JP
@@ -1566,7 +1566,7 @@ tty_putstr(window, attr, str)
     register int i, j, n0;
 /*JP*/
     int kchar2 = 0;		/* if 1, kanji 2nd byte */
-    unsigned char uc;
+/*  unsigned char uc;*/
 
     /* Assume there's a real problem if the window is missing --
      * probably a panic message
@@ -2187,7 +2187,7 @@ int in_ch;
 	    graph_on();
 	    GFlag = TRUE;
 	}
-/*	(void) putchar((ch ^ 0x80)); /* Strip 8th bit */
+/*	(void) putchar((ch ^ 0x80));*/ /* Strip 8th bit */
 	(void) cputchar((ch ^ 0x80)); /* Strip 8th bit */
     } else {
 	if (GFlag) {
